==> ejc-zdsstore-api-3.0.0-20231224.063958-32-sources.jar: com/ejianc/business/zdsstore/hystrix/StoreManageHystrix.java <==
package com.ejianc.business.zdsstore.hystrix;

import com.ejianc.business.zdsstore.api.IStoreManageApi;
import com.ejianc.business.zdsstore.vo.FlowVO;
import com.ejianc.business.zdsstore.vo.OutFlowVO;
import com.ejianc.business.zdsstore.vo.StoreManageVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;

@Component
public class StoreManageHystrix implements IStoreManageApi {


    /**
     * @param storeManageVO
     * @description: 出入库操作
     * @author songlx
     * @date: 2022/1/17
     */
    @Override
    public CommonResponse<StoreManageVO> inOutStore(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO 数据
     * @description: 出入库逆向操作
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/1/17
     */
    @Override
    public CommonResponse<StoreManageVO> inOutStoreRollback(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 查询物资库存现存量库存均价
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/2/9
     */
    @Override
    public CommonResponse<StoreManageVO> surplusMaterialPrice(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 更新摊销金额
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/3/2
     */
    @Override
    public CommonResponse<StoreManageVO> updateShareMny(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 周转材库存现存量库存均价
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/3/3
     */
    @Override
    public CommonResponse<StoreManageVO> turnSurplusMaterialPrice(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<FlowVO>> getFlowListByContractId(OutFlowVO outFlowVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> queryInstoreTaxMnyByPurchaseContractId(OutFlowVO outFlowVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
}

==> ejc-zdsstore-api-3.0.0-20240128.053754-162-sources.jar: com/ejianc/business/zdsstore/hystrix/StoreManageHystrix.java <==
package com.ejianc.business.zdsstore.hystrix;

import com.ejianc.business.zdsstore.api.IStoreManageApi;
import com.ejianc.business.zdsstore.vo.FlowVO;
import com.ejianc.business.zdsstore.vo.OutFlowVO;
import com.ejianc.business.zdsstore.vo.StoreManageVO;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;

@Component
public class StoreManageHystrix implements IStoreManageApi {


    /**
     * @param storeManageVO
     * @description: 出入库操作
     * @author songlx
     * @date: 2022/1/17
     */
    @Override
    public CommonResponse<StoreManageVO> inOutStore(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO 数据
     * @description: 出入库逆向操作
     * @return: com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     * @author songlx
     * @date: 2022/1/17
     */
    @Override
    public CommonResponse<StoreManageVO> inOutStoreRollback(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 查询物资库存现存量库存均价
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/2/9
     */
    @Override
    public CommonResponse<StoreManageVO> surplusMaterialPrice(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 更新摊销金额
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/3/2
     */
    @Override
    public CommonResponse<StoreManageVO> updateShareMny(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    /**
     * @param storeManageVO
     * @description: 周转材库存现存量库存均价
     * @return: com.ejianc.framework.core.response.CommonResponse<com.ejianc.business.store.vo.StoreManageVO>
     * @author songlx
     * @date: 2022/3/3
     */
    @Override
    public CommonResponse<StoreManageVO> turnSurplusMaterialPrice(StoreManageVO storeManageVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<FlowVO>> getFlowListByContractId(OutFlowVO outFlowVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<BigDecimal> queryInstoreTaxMnyByPurchaseContractId(OutFlowVO outFlowVO) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<StoreManageVO>> inOutStoreBatch(List<StoreManageVO> storeManageVOList) {
        return CommonResponse.error("网络问题， 查询失败。");
    }

    @Override
    public CommonResponse<List<StoreManageVO>> inOutStoreRollbackBatch(List<StoreManageVO> storeManageVOList) {
        return CommonResponse.error("网络问题， 查询失败。");
    }
}
